#############################################################
#
#   Program: ols_model1.R
#   Project: The Impact of Provider on Delay to Testing
#   PI: Carolyn Audet
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: A linear regression may identify whether
#            patient/provider characteristics increase 
#            time to testing
#   Created: 
#   Revisions: 
#     
#
#############################################################
set.seed(2)

data$sex <- data$sex.factor
data$community <- data$commun.factor
library(rms)
ols1.d1 <- data[!is.na(data$delaytime),]
ols1.dd1 <- datadist(with(ols1.d1,data.frame(sex,age,community,civilstatus.factor,education,langinhouse___1.factor,distanceclinic,transtoclinic.factor,delaytime,hivknow,cd4,religioushelp.factor,numhealers.factor)))
ols1.mi <- aregImpute(~sex+age+community+civilstatus.factor+education+langinhouse___1.factor+distanceclinic+transtoclinic.factor+delaytime+cd4 + religioushelp.factor+numhealers.factor,n.impute=25,data=ols1.d1) 
options(datadist='ols1.dd1')

########## MODEL 1: ORDINARY LEAST SQUARES
ols1.noimp <- ols(log(delaytime) ~ sex+rcs(age,3)+education+distanceclinic+transtoclinic.factor+numhealers.factor+community, data=ols1.d1)
ols1.nl1 <- fit.mult.impute(log(delaytime) ~ sex+rcs(age,3)+rcs(education,4)+rcs(distanceclinic,4)+transtoclinic.factor+numhealers.factor + religioushelp.factor+community, ols, ols1.mi, ols1.d1)
ols1.nl2 <- fit.mult.impute(log(delaytime) ~ sex+rcs(age,3)+rcs(education,4)+distanceclinic+transtoclinic.factor+numhealers.factor + religioushelp.factor+community, ols, ols1.mi, ols1.d1)
ols1.int <- fit.mult.impute(log(delaytime) ~ sex+rcs(age,3)+education+distanceclinic+transtoclinic.factor+numhealers.factor * religioushelp.factor+community, ols, ols1.mi, ols1.d1)
ols1 <- fit.mult.impute(log(delaytime) ~ sex+rcs(age,3)+education+distanceclinic+transtoclinic.factor+numhealers.factor + religioushelp.factor+community, ols, ols1.mi, ols1.d1)

getols1 <- as.data.frame(anova(ols1))

plot(ols1$residuals~ols1$fitted.values)
scatter.smooth(ols1$residuals~ols1$fitted.values,span=1/10,col=5)
abline(h=0)
## LOOK OKAY... AFTER LOG TRANFORMATION 

olssum1 <- summary(ols1,age=c(30,20),education=c(2,6),distanceclinic=c(30,60),numhealers.factor="No healer",sex="Male",religioushelp.factor="No",community="Namacurra")[c(4,1,2,3,5,6,7,8,9,10:13),c(4,6,7)]
olssum2 <- summary(ols1,age=c(30,40),education=c(2,6),distanceclinic=c(30,60),numhealers.factor="No healer",sex="Male",religioushelp.factor="No",community="Namacurra")[1,c(4,6,7)]
olssum3 <- summary(ols1,age=c(30,50),education=c(2,6),distanceclinic=c(30,60),numhealers.factor="No healer",sex="Male",religioushelp.factor="No",community="Namacurra")[1,c(4,6,7)]
olssum <- rbind(olssum1[1:2,],olssum2,olssum3,olssum1[3:13,])

ols1.labels <- c("Female","Age","\\\\hspace{.25in} 20 years","\\\\hspace{.25in} 30 years (ref)","\\\\hspace{.25in} 40 years","\\\\hspace{.25in} 50 years","Education (per 2 years)",
		 "Travel time to clinic (per 30 minutes)","Transportation","\\\\hspace{.25in}Walk (ref)","\\\\hspace{.25in} Bike","\\\\hspace{.25in} Car/motorcycle",
                 "Traditional healer (TH) use","\\\\hspace{.25in}Did not consult TH (ref)","\\\\hspace{.25in} Consulted 1 TH","\\\\hspace{.25in} Consulted 2 TH",
                 "\\\\hspace{.25in} Consulted 3 TH","\\\\hspace{.25in} Consulted 4 TH","\\\\hspace{.25in} Consulted 5 or more TH",
                 "Consulted religious leader","Community","\\\\hspace{.25in} Namacurra (ref)","\\\\hspace{.25in} Inhassunge") 
		 
myformat <- function(x){format(round(exp(x),2),nsmall=2)}
olssumlines1 <- paste(paste(sapply(olssum[,1],myformat)," (",sapply(olssum[,2],myformat),", ",sapply(olssum[,3],myformat),")",sep=""),sep=" & ")
olssumlines2 <- c(olssumlines1[1],"",olssumlines1[2],"1",olssumlines1[3:6],"","1",olssumlines1[7:8],"","1",olssumlines1[9:14],"","1",olssumlines1[15])
ols1pval <- c(sapply(getols1$P[c(1:2)],myformat4),rep("",4),sapply(getols1$P[c(4:6)],myformat4),rep("",3),sapply(getols1$P[c(7)],myformat4),rep("",6),sapply(getols1$P[c(8:9)],myformat4),rep("",2))
ols1table <- paste(ols1.labels,olssumlines2,ols1pval,sep=" & ")
ols1tabletex <- paste(ols1table,collapse=" \\\\\\\\ ")


ols1p1 <- Predict(ols1,numhealers.factor=NA,fun=exp)
print(plot(ols1p1))

ols1p2 <- Predict(ols1,age=NA,fun=exp)
print(plot(ols1p2))

print1pred1 <- data.frame(ols1p1)[,c(6,9:11)]
print1pred1$est <- paste(round(print1pred1$yhat)," days (",round(print1pred1$lower),", ",round(print1pred1$upper),")",sep="")
print1pred2 <- with(print1pred1,data.frame(numhealers.factor,est))
print1predlatex <- paste(apply(print1pred2,1,paste,collapse=" & "),collapse=" \\\\\\\\ ")




