##############################################################
#
#   Program: ols_model2.R
#   Project: The Impact of Provider on Delay to Testing
#   PI: Carolyn Audet
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: A linear regression may identify whether
#            patient/provider characteristics increase 
#            time to testing
#   Created: 
#   Revisions: 
#     
#
#############################################################
set.seed(2)
library(rms)
ols2.d1 <- data[!is.na(data$delaytime),]
ols2.dd1 <- datadist(with(ols2.d1,data.frame(sex,age,community,civilstatus.factor,education,langinhouse___1.factor,distanceclinic,transtoclinic.factor,delaytime,hivknow,cd4,religioushelp.factor,visitthbefore.factor)))
ols2.mi <- aregImpute(~sex+age+community+civilstatus.factor+education+langinhouse___1.factor+distanceclinic+transtoclinic.factor+delaytime+cd4 + religioushelp.factor+visitthbefore.factor,n.impute=25,data=ols2.d1) 
options(datadist='ols2.dd1')

########## MODEL 1: ORDINARY LEAST SQUARES
ols2.noimp <- ols(log(delaytime) ~ sex+rcs(age,3)+education+distanceclinic+transtoclinic.factor+visitthbefore.factor+community, data=ols2.d1)
ols2.nl1 <- fit.mult.impute(log(delaytime) ~ sex+rcs(age,3)+rcs(education,4)+rcs(distanceclinic,4)+transtoclinic.factor+visitthbefore.factor + religioushelp.factor+community, ols, ols2.mi, ols2.d1)
ols2.nl2 <- fit.mult.impute(log(delaytime) ~ sex+rcs(age,3)+rcs(education,4)+distanceclinic+transtoclinic.factor+visitthbefore.factor + religioushelp.factor+community, ols, ols2.mi, ols2.d1)
ols2.int <- fit.mult.impute(log(delaytime) ~ sex+rcs(age,3)+education+distanceclinic+transtoclinic.factor+visitthbefore.factor * religioushelp.factor+community, ols, ols2.mi, ols2.d1)
ols2 <- fit.mult.impute(log(delaytime) ~ sex+rcs(age,3)+education+distanceclinic+transtoclinic.factor+visitthbefore.factor + religioushelp.factor+community, ols, ols2.mi, ols2.d1)

getols2 <- as.data.frame(anova(ols2))

plot(ols2$residuals~ols2$fitted.values)
scatter.smooth(ols2$residuals~ols2$fitted.values,span=1/10,col=5)
abline(h=0)
## LOOK OKAY... AFTER LOG TRANFORMATION 

olssum1 <- summary(ols2,age=c(30,20),education=c(2,6),distanceclinic=c(30,60),visitthbefore.factor="No TH",sex="Male",religioushelp.factor="No",community="Namacurra")[c(4,1,2,3,5,6,7,8,9),c(4,6,7)]
olssum2 <- summary(ols2,age=c(30,40),education=c(2,6),distanceclinic=c(30,60),visitthbefore.factor="No TH",sex="Male",religioushelp.factor="No",community="Namacurra")[1,c(4,6,7)]
olssum3 <- summary(ols2,age=c(30,50),education=c(2,6),distanceclinic=c(30,60),visitthbefore.factor="No TH",sex="Male",religioushelp.factor="No",community="Namacurra")[1,c(4,6,7)]
olssum <- rbind(olssum1[1:2,],olssum2,olssum3,olssum1[3:9,])

ols2.labels <- c("Female","Age","\\\\hspace{.25in} 20 years","\\\\hspace{.25in} 30 years (ref)","\\\\hspace{.25in} 40 years","\\\\hspace{.25in} 50 years","Education (per 2 years)",
		 "Travel time to clinic (per 30 minutes)","Transportation","\\\\hspace{.25in}Walk (ref)","\\\\hspace{.25in} Bike","\\\\hspace{.25in} Car/motorcycle",
                 "Traditional healer (TH) use","\\\\hspace{.25in}Did not consult TH (ref)","\\\\hspace{.25in} Consulted any TH",
                 "Consulted religious leader","Community","\\\\hspace{.25in} Namacurra (ref)","\\\\hspace{.25in} Inhassunge") 
		 
myformat <- function(x){format(round(exp(x),2),nsmall=2)}
olssumlines1 <- paste(paste(sapply(olssum[,1],myformat)," (",sapply(olssum[,2],myformat),", ",sapply(olssum[,3],myformat),")",sep=""),sep=" & ")
olssumlines2 <- c(olssumlines1[1],"",olssumlines1[2],"1",olssumlines1[3:6],"","1",olssumlines1[7:8],"","1",olssumlines1[9:10],"","1",olssumlines1[11])
ols2pval <- c(sapply(getols2$P[c(1:2)],myformat4),rep("",4),sapply(getols2$P[c(4:6)],myformat4),rep("",3),sapply(getols2$P[c(7)],myformat4),rep("",2),sapply(getols2$P[c(8:9)],myformat4),rep("",2))
ols2table <- paste(ols2.labels,olssumlines2,ols2pval,sep=" & ")
ols2tabletex <- paste(ols2table,collapse=" \\\\\\\\ ")


ols2p1 <- Predict(ols2,visitthbefore.factor=NA,fun=exp)
print(plot(ols2p1))

ols2p2 <- Predict(ols2,age=NA,fun=exp)
print(plot(ols2p2))

print2pred1 <- data.frame(ols2p1)[2:1,c(6,9:11)]
print2pred1$est <- paste(round(print2pred1$yhat)," days (",round(print2pred1$lower),", ",round(print2pred1$upper),")",sep="")
print2pred2 <- with(print2pred1,data.frame(visitthbefore.factor,est))
print2predlatex <- paste(apply(print2pred2,1,paste,collapse=" & "),collapse=" \\\\\\\\ ")

